@@ -282,7 +282,7 @@ sub store_file_from_fh {
                     }
                 }
                 else {
-                    $self->fail_write_attempt->("Got non-200 from remote server $top");
+                    $self->fail_write_attempt("Got non-200 from remote server $top");
                     next;
                 }
             }
